Django Middleware Package
=========================

Visualize what SQL Query is being executed with additional stats.


Installation
------------
1. Install the package using pip:

    pip install django-orm-2-sql-visualizer

2. Add the middleware to your settings.py file:

    'orm-2-sql-visualizer.middleware.new_middleware',

